==> igniteui-react-charts-16.4.1.tgz: package/ES2015/RangeAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalRangeCategorySeries } from "./HorizontalRangeCategorySeries";
import { Array_$type, typeCast, runOn, markType } from "igniteui-react-core/ES2015/type";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Polyline } from "igniteui-react-core/ES2015/Polyline";
import { Polygon } from "igniteui-react-core/ES2015/Polygon";
import { ScalerParams } from "./ScalerParams";
import { isNaN_ } from "igniteui-react-core/ES2015/number";
import { RangeCategorySeriesView } from "./RangeCategorySeriesView";
export class RangeAreaSeries extends HorizontalRangeCategorySeries {
    constructor() {
        super();
        this.ab = RangeAreaSeries.$;
    }
    bf() {
        return new RangeAreaSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.o9 = a;
    }
    get_ck() {
        return true;
    }
    get ck() {
        return this.get_ck();
    }
    pa(a, b, c, d) {
        if (isNaN_(b.x) || isNaN_(b.y)) {
            return false;
        }
        if (isNaN_(c.x) || isNaN_(c.y)) {
            return false;
        }
        if ((a.y <= b.y && a.y >= c.y)) {
            return true;
        }
        return false;
    }
    df(a, b) {
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    preferredCategoryMode(a) {
        return 0;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.cx();
    }
    oe(a, b) {
        super.oe(a, b);
        let c = a.f.count;
        let d = new List$1(Array_$type, 2, c);
        for (let e = 0; e < c; e++) {
            let f = a.f._inner[e];
            let g = new Array(4);
            g[0] = f[0];
            g[1] = f[1];
            let h = a.f._inner[a.f.count - 1 - e];
            g[2] = h[0];
            g[3] = h[2];
            d.add(g);
        }
        let i = typeCast(RangeAreaSeriesView.$, b);
        let j = this.getEffectiveViewport1(i);
        this.m5.x(this, this.nq(), this.xAxis, runOn(this, this.mr), this.ny(b), this.nz(b));
        let k = false;
        let l = this.m5.c;
        if (l != null) {
            k = true;
        }
        if (k) {
            let m = new ScalerParams(0, b.bq, b.bp, this.xAxis.b8, j);
            this.oa(d, -1, this.lowColumn.count, this.xAxis, m, b.n);
        }
        let n = i.c5;
        let o = i.c7;
        let p = i.c1;
        this.m5.ae(n, true, false, true, true);
        this.m5.ae(o, true, false, true, true);
        this.m5.ae(p, false, true, false, false);
        if (b.cp(a)) {
            i.cy(a.f.count, d, false);
            b.cs(a);
        }
        i.c1._opacity = this.m5.i * this.d2;
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
RangeAreaSeries.$t = markType(RangeAreaSeries, 'RangeAreaSeries', HorizontalRangeCategorySeries.$);
export class RangeAreaSeriesView extends RangeCategorySeriesView {
    constructor(a) {
        super(a);
        this.cw = null;
        this.c4 = new Polyline();
        this.c0 = new Polygon();
        this.c6 = new Polyline();
        this.c3 = new Polyline();
        this.c2 = new Polyline();
        this.cz = new Polygon();
        this.cw = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    get c5() {
        return this.c4;
    }
    get c1() {
        return this.c0;
    }
    get c7() {
        return this.c6;
    }
    cx() {
        this.c0.aj.clear();
        this.c4.aj.clear();
        this.c6.aj.clear();
    }
    cy(a, b, c) {
        this.cv(this.c4, this.c0, this.c6, a, b, c);
        this.an();
    }
    a9() {
        super.a9();
        this.c2.aj = this.c4.aj;
        this.c3.aj = this.c6.aj;
        this.cz.aj = this.c0.aj;
        let a = this.bk();
        this.c2._stroke = a;
        this.c2.ac = this.e.eu + 3;
        this.c3._stroke = a;
        this.c3.ac = this.e.eu + 3;
        this.cz._fill = a;
        this.cz._opacity = 1;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.t(this.cz);
                a.u(this.c2);
                a.u(this.c3);
            }
            else {
                a.t(this.c0);
                a.u(this.c4);
                a.u(this.c6);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPolylineData(a, this.c4, "lowerShape", ["Lower"]);
        this.e.a2.exportPolylineData(a, this.c6, "upperShape", ["Upper", "Main"]);
        this.e.a2.exportPolygonData(a, this.c0, "fillShape", ["Fill"]);
    }
}
RangeAreaSeriesView.$t = markType(RangeAreaSeriesView, 'RangeAreaSeriesView', RangeCategorySeriesView.$);

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/RangeAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalRangeCategorySeries } from "./HorizontalRangeCategorySeries";
import { Array_$type, typeCast, runOn, markType } from "igniteui-react-core/ES2015/type";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Polyline } from "igniteui-react-core/ES2015/Polyline";
import { Polygon } from "igniteui-react-core/ES2015/Polygon";
import { ScalerParams } from "./ScalerParams";
import { isNaN_ } from "igniteui-react-core/ES2015/number";
import { RangeCategorySeriesView } from "./RangeCategorySeriesView";
export class RangeAreaSeries extends HorizontalRangeCategorySeries {
    constructor() {
        super();
        this.ab = RangeAreaSeries.$;
    }
    bf() {
        return new RangeAreaSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.pa = a;
    }
    get_ck() {
        return true;
    }
    pb(a, b, c, d) {
        if (isNaN_(b.x) || isNaN_(b.y)) {
            return false;
        }
        if (isNaN_(c.x) || isNaN_(c.y)) {
            return false;
        }
        if ((a.y <= b.y && a.y >= c.y)) {
            return true;
        }
        return false;
    }
    df(a, b) {
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    preferredCategoryMode(a) {
        return 0;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.cz();
    }
    of(a, b) {
        super.of(a, b);
        let c = a.f.count;
        let d = new List$1(Array_$type, 2, c);
        for (let e = 0; e < c; e++) {
            let f = a.f._inner[e];
            let g = new Array(4);
            g[0] = f[0];
            g[1] = f[1];
            let h = a.f._inner[a.f.count - 1 - e];
            g[2] = h[0];
            g[3] = h[2];
            d.add(g);
        }
        let i = typeCast(RangeAreaSeriesView.$, b);
        let j = this.getEffectiveViewport1(i);
        this.m5.x(this, this.nq(), this.xAxis, runOn(this, this.mr), this.ny(b), this.nz(b));
        let k = false;
        let l = this.m5.c;
        if (l != null) {
            k = true;
        }
        if (k) {
            let m = new ScalerParams(0, b.bs, b.br, this.xAxis.b8, j);
            this.ob(d, -1, this.lowColumn.count, this.xAxis, m, b.n);
        }
        let n = i.c7;
        let o = i.c9;
        let p = i.c3;
        this.m5.ae(n, true, false, true, true);
        this.m5.ae(o, true, false, true, true);
        this.m5.ae(p, false, true, false, false);
        if (b.cr(a)) {
            i.c0(a.f.count, d, false);
            b.cu(a);
        }
        i.c3._opacity = this.m5.i * this.d2;
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
RangeAreaSeries.$t = markType(RangeAreaSeries, 'RangeAreaSeries', HorizontalRangeCategorySeries.$);
export class RangeAreaSeriesView extends RangeCategorySeriesView {
    constructor(a) {
        super(a);
        this.cy = null;
        this.c6 = new Polyline();
        this.c2 = new Polygon();
        this.c8 = new Polyline();
        this.c5 = new Polyline();
        this.c4 = new Polyline();
        this.c1 = new Polygon();
        this.cy = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    get c7() {
        return this.c6;
    }
    get c3() {
        return this.c2;
    }
    get c9() {
        return this.c8;
    }
    cz() {
        this.c2.aj.clear();
        this.c6.aj.clear();
        this.c8.aj.clear();
    }
    c0(a, b, c) {
        this.cx(this.c6, this.c2, this.c8, a, b, c);
        this.an();
    }
    a9() {
        super.a9();
        this.c4.aj = this.c6.aj;
        this.c5.aj = this.c8.aj;
        this.c1.aj = this.c2.aj;
        let a = this.bl();
        this.c4._stroke = a;
        this.c4.ac = this.e.eu + 3;
        this.c5._stroke = a;
        this.c5.ac = this.e.eu + 3;
        this.c1._fill = a;
        this.c1._opacity = 1;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.t(this.c1);
                a.u(this.c4);
                a.u(this.c5);
            }
            else {
                a.t(this.c2);
                a.u(this.c6);
                a.u(this.c8);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPolylineData(a, this.c6, "lowerShape", ["Lower"]);
        this.e.a2.exportPolylineData(a, this.c8, "upperShape", ["Upper", "Main"]);
        this.e.a2.exportPolygonData(a, this.c2, "fillShape", ["Fill"]);
    }
}
RangeAreaSeriesView.$t = markType(RangeAreaSeriesView, 'RangeAreaSeriesView', RangeCategorySeriesView.$);
